starcluster.exception

Package starcluster :: Module exception |
[hide private]
[frames] | no frames]

# Module exception

source code

StarCluster Exception Classes

Classes | [hide private]
| BaseException
| CommandNotFound Raised when command is not found on the system's PATH
| RemoteCommandNotFound Raised when command is not found on a *remote* system's PATH
| SSHError Base class for all SSH related errors
| SSHConnectionError Raised when ssh fails to to connect to a host (socket error)
| SSHAuthException Raised when an ssh connection fails to authenticate
| SSHNoCredentialsError
| AWSError Base exception for all AWS related errors
| RegionDoesNotExist
| AMIDoesNotExist
| InstanceDoesNotExist
| InstanceNotRunning
| SecurityGroupDoesNotExist
| KeyPairDoesNotExist
| ZoneDoesNotExist
| VolumeDoesNotExist
| SnapshotDoesNotExist
| BucketAlreadyExists
| BucketDoesNotExist
| InvalidOperation
| InvalidBucketName
| InvalidImageName
| AWSUserIdRequired
| EC2CertRequired
| EC2PrivateKeyRequired
| EC2CertDoesNotExist
| EC2PrivateKeyDoesNotExist
| SpotHistoryError
| InvalidIsoDate
| ConfigError Base class for all config related errors
| ConfigSectionMissing
| ConfigHasNoSections
| PluginNotFound
| NoDefaultTemplateFound
| ConfigNotFound
| KeyNotFound
| InvalidDevice
| InvalidPartition
| PluginError Base class for plugin errors
| PluginLoadError Raised when an error is encountered while loading a plugin
| PluginSyntaxError Raised when plugin contains syntax errors
| ValidationError Base class for validation related errors
| ClusterReceiptError Raised when creating/loading a cluster receipt fails
| ClusterValidationError Cluster validation related errors
| IncompatibleSettings Raised when two or more settings conflict with each other
| InvalidProtocol Raised when user specifies an invalid IP protocol for permission
| InvalidPortRange Raised when user specifies an invalid port range for permission
| InvalidCIDRSpecified Raised when user specifies an invalid CIDR ip for permission
| InvalidZone Raised when a zone has been specified that does not match the common zone of the volumes being attached
| VolumesZoneError
| ClusterTemplateDoesNotExist Exception raised when user requests a cluster template that does not exist
| ClusterNotRunning Exception raised when user requests a running cluster that does not exist
| ClusterDoesNotExist Exception raised when user requests a running cluster that does not exist
| ClusterExists
| CancelledStartRequest
| CancelledCreateVolume
| CancelledCreateImage
| CancelledS3ImageCreation
| CancelledEBSImageCreation
| ExperimentalFeature
| ThreadPoolException
| IncompatibleCluster

Variables | [hide private]
| __package__ = ``'``starcluster``'``